@@ -1,6 +1,7 @@
 import unittest
 import mock
 import requests
+import sys
 from fitbit import Fitbit
 from fitbit import exceptions
 
@@ -76,6 +77,24 @@ class ExceptionTest(unittest.TestCase):
         r.status_code = 499
         self.assertRaises(exceptions.HTTPBadRequest, f.user_profile_get)
 
+    def test_too_many_requests(self):
+        """
+        Tests the 429 response, given in case of exceeding the rate limit
+        """
+        r = mock.Mock(spec=requests.Response)
+        r.content = b"{'normal': 'resource'}"
+        r.headers = {'Retry-After': '10'}
+
+        f = Fitbit(**self.client_kwargs)
+        f.client._request = lambda *args, **kwargs: r
+
+        r.status_code = 429
+        try:
+            f.user_profile_get()
+            self.assertEqual(True, False)  # Won't run if an exception's raised
+        except exceptions.HTTPTooManyRequests:
+            e = sys.exc_info()[1]
+            self.assertEqual(e.retry_after_secs, 10)
 
     def test_serialization(self):
         """
@@ -100,4 +119,3 @@ class ExceptionTest(unittest.TestCase):
         f = Fitbit(**self.client_kwargs)
         f.client._request = lambda *args, **kwargs: r
         self.assertRaises(exceptions.DeleteError, f.delete_activities, 12345)
-
